@@ -32,7 +32,9 @@ class SpellingBuilder(Builder):
     def init(self):
         self.docnames = []
         self.document_data = []
+        self.misspelling_count = 0
 
+        self.env.settings["smart_quotes"] = False
         # Initialize the per-document filters
         if not hasattr(self.env, 'spelling_document_filters'):
             self.env.spelling_document_filters = collections.defaultdict(list)
@@ -43,20 +45,26 @@ class SpellingBuilder(Builder):
             EmailFilter,
         ]
         if self.config.spelling_ignore_wiki_words:
+            self.info('Ignoring wiki words')
             f.append(WikiWordFilter)
         if self.config.spelling_ignore_acronyms:
+            self.info('Ignoring acronyms')
             f.append(filters.AcronymFilter)
         if self.config.spelling_ignore_pypi_package_names:
             self.info('Adding package names from PyPI to local dictionary...')
             f.append(filters.PyPIFilterFactory())
         if self.config.spelling_ignore_python_builtins:
+            self.info('Ignoring Python builtins')
             f.append(filters.PythonBuiltinsFilter)
         if self.config.spelling_ignore_importable_modules:
+            self.info('Ignoring importable module names')
             f.append(filters.ImportableModuleFilter)
         f.extend(self.config.spelling_filters)
 
         project_words = os.path.join(self.srcdir,
                                      self.config.spelling_word_list_filename)
+        self.info('Looking for custom word list in {}'.format(
+            project_words))
         self.checker = checker.SpellingChecker(
             lang=self.config.spelling_lang,
             tokenizer_lang=self.config.tokenizer_lang,
@@ -109,7 +117,7 @@ class SpellingBuilder(Builder):
                 parent = node
                 seen = set()
                 while lineno is None:
-                    #self.info('looking for line number on %r' % node)
+                    # self.info('looking for line number on %r' % node)
                     seen.add(parent)
                     parent = node.parent
                     if parent is None or parent in seen:
@@ -130,10 +138,7 @@ class SpellingBuilder(Builder):
                         lineno, word,
                         self.format_suggestions(suggestions),
                     ))
-
-                    # We found at least one bad spelling, so set the status
-                    # code for the app to a value that indicates an error.
-                    self.app.statuscode = 1
+                    self.misspelling_count += 1
 
         self.checker.pop_filters()
         return
@@ -142,4 +147,6 @@ class SpellingBuilder(Builder):
         self.output.close()
         self.info('Spelling checker messages written to %s' %
                   self.output_filename)
+        if self.misspelling_count:
+            self.warn('Found %d misspelled words' % self.misspelling_count)
         return
